==> haskell-http-common-0.8.3.4-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-common
version:              0.8.3.4
visibility:           public
id:                   http-common-0.8.3.4-95CLLV0XNASGXZUm5O90AU
key:                  http-common-0.8.3.4-95CLLV0XNASGXZUm5O90AU
license:              BSD-3-Clause
copyright:            © 2012-2021 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-common
synopsis:             Common types for HTTP clients and servers
description:
    /Overview/

    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.

category:             Web
abi:                  fdc50e38b77ee3f5c03c61523e9df736
exposed:              True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/http-common-0.8.3.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/http-common-0.8.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-common
hs-libraries:         HShttp-common-0.8.3.4-95CLLV0XNASGXZUm5O90AU
depends:
    base-4.15.1.0 base64-bytestring-1.2.1.0-HEQxSB8A48p9GgtQTdJmdN
    blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU bytestring-0.10.12.1
    case-insensitive-1.2.1.0-EU6m29w1unz38yqdCvBbWB directory-1.3.6.2
    mtl-2.2.2 network-3.1.2.7-IOzKcVzyp93ERMKYVerDZf
    random-1.2.1.1-HP1Jl4dlbgf891wCLsy6Z9 text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-FiUFtsHtx28IfDtF4iaH6c

haddock-interfaces:   /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html:         /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-common-0.8.3.4-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-common
version:              0.8.3.4
visibility:           public
id:                   http-common-0.8.3.4-AeLYoljgJvk4EBEEIrv3hT
key:                  http-common-0.8.3.4-AeLYoljgJvk4EBEEIrv3hT
license:              BSD-3-Clause
copyright:            © 2012-2021 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-common
synopsis:             Common types for HTTP clients and servers
description:
    /Overview/

    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.

category:             Web
abi:                  519acaff73b32dcd60b5a1aa7cbe8b77
exposed:              True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/http-common-0.8.3.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/http-common-0.8.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-common
hs-libraries:         HShttp-common-0.8.3.4-AeLYoljgJvk4EBEEIrv3hT
depends:
    base-4.15.1.0 base64-bytestring-1.2.1.0-KbN6G8Oab0JGXDIOSmHWBi
    blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU bytestring-0.10.12.1
    case-insensitive-1.2.1.0-8mrHMIrC8PIAA1uK08bdKY directory-1.3.6.2
    mtl-2.2.2 network-3.1.2.7-LWaASFO68LfCrj9dzFk83a
    random-1.2.1.1-8Yy442tDgI9KXa8FjBISNx text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-Egpruffujfv1ZeuVmASDK2

haddock-interfaces:   /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html:         /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
